@@ -3,5 +3,5 @@ from pydantic import BaseModel
 from .ip_address import IpAddressModel
 
 
-class NetworkHost(BaseModel):
+class NetworkHostModel(BaseModel):
     ip_address: IpAddressModel
